==> feel-engine-1.17.0-sources.jar: org/camunda/feel/api/EvaluationFailureType.scala <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.feel.api

sealed trait EvaluationFailureType

/**
  * Defines the type of an evaluation failure.
  */
object EvaluationFailureType {

  case object UNKNOWN extends EvaluationFailureType

  case object NO_VARIABLE_FOUND extends EvaluationFailureType

  case object NO_CONTEXT_ENTRY_FOUND extends EvaluationFailureType

  case object NO_PROPERTY_FOUND extends EvaluationFailureType

  case object NOT_COMPARABLE extends EvaluationFailureType

  case object INVALID_TYPE extends EvaluationFailureType

  case object NO_FUNCTION_FOUND extends EvaluationFailureType

  case object FUNCTION_INVOCATION_FAILURE extends EvaluationFailureType

  case object ASSERT_FAILURE extends EvaluationFailureType

}

==> feel-engine-1.18.0-sources.jar: org/camunda/feel/api/EvaluationFailureType.scala <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.feel.api

sealed trait EvaluationFailureType

/** Defines the type of an evaluation failure.
  */
object EvaluationFailureType {

  case object UNKNOWN extends EvaluationFailureType

  case object NO_VARIABLE_FOUND extends EvaluationFailureType

  case object NO_CONTEXT_ENTRY_FOUND extends EvaluationFailureType

  case object NO_PROPERTY_FOUND extends EvaluationFailureType

  case object NOT_COMPARABLE extends EvaluationFailureType

  case object INVALID_TYPE extends EvaluationFailureType

  case object NO_FUNCTION_FOUND extends EvaluationFailureType

  case object FUNCTION_INVOCATION_FAILURE extends EvaluationFailureType

  case object ASSERT_FAILURE extends EvaluationFailureType

}
